@@ -83,7 +83,7 @@ void ConfigElem::init( )
 {
   //initialize timeout timer
   pop3Timer = new TQTimer( this );
-  connect( pop3Timer, SIGNAL( timeout() ), this, SLOT( slotTimeout() ) );
+  connect( pop3Timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotTimeout() ) );
 
   //state is idle
   state = AccountIdle;
@@ -290,7 +290,7 @@ bool ConfigElem::assertPassword( bool force )
     while( TQApplication::overrideCursor() )
       TQApplication::restoreOverrideCursor();
 
-    TQCString password;      //for the password dialog to store the password
+    TQString password;      //for the password dialog to store the password
     int result = KPasswordDialog::getPassword( password, i18n( "Please type in the password for %1" ).arg( getAccountName() ) );
 
     //set waiting cursor
@@ -351,7 +351,7 @@ void ConfigElem::deleteNextMail( )
 
   //start job
   startKIOJob( TQString( "/remove/%1" ).arg( *MailsToDelete.begin() ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotMailDeleted( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotMailDeleted( TDEIO::Job* ) ) );
 }
 
 void ConfigElem::slotMailDeleted( TDEIO::Job* job )
@@ -483,7 +483,7 @@ void ConfigElem::commitDeletion( )
 {
   //start job to commit
   startKIOJob( TQString( "/commit" ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotFinalizeDeletion( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotFinalizeDeletion( TDEIO::Job* ) ) );
 }
 
 unsigned int ConfigElem::getTimeoutTime( )
@@ -586,8 +586,8 @@ void ConfigElem::showNextMail( )
 
   //start job
   startKIOJob( TQString( "/download/%1" ).arg( *MailsToShow.begin() ) );
-  connect( pop3Job, SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), SLOT( slotDataMailBody( TDEIO::Job*, const TQByteArray & ) ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotBodyDownloaded( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), TQ_SLOT( slotDataMailBody( TDEIO::Job*, const TQByteArray & ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotBodyDownloaded( TDEIO::Job* ) ) );
 
 }
 
@@ -692,7 +692,7 @@ void ConfigElem::commitDownloading( )
 {
   //start job to commit
   startKIOJob( TQString( "/commit" ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotFinalizeShowMail( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotFinalizeShowMail( TDEIO::Job* ) ) );
 }
 
 void ConfigElem::refreshMailList( FilterLog* log )
@@ -744,8 +744,8 @@ void ConfigElem::getUIDs( )
 
   //start job
   startKIOJob( TQString( "/uidl" ) );
-  connect( pop3Job, SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), SLOT( slotReceiveUID( TDEIO::Job*, const TQByteArray & ) ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotUIDsReceived( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), TQ_SLOT( slotReceiveUID( TDEIO::Job*, const TQByteArray & ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotUIDsReceived( TDEIO::Job* ) ) );
 
 }
 
@@ -917,7 +917,7 @@ void ConfigElem::commitRefresh( )
 {
   //start job to commit
   startKIOJob( TQString( "/commit" ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotFinalizeRefresh( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotFinalizeRefresh( TDEIO::Job* ) ) );
 }
 
 void ConfigElem::getSizes( )
@@ -927,8 +927,8 @@ void ConfigElem::getSizes( )
 
   //start job
   startKIOJob( TQString( "/index" ) );
-  connect( pop3Job, SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), SLOT( slotReceiveSize( TDEIO::Job*, const TQByteArray & ) ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotSizesReceived( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), TQ_SLOT( slotReceiveSize( TDEIO::Job*, const TQByteArray & ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotSizesReceived( TDEIO::Job* ) ) );
 
 }
 
@@ -1055,8 +1055,8 @@ void ConfigElem::getNextHeader( )
 
   //start job
   startKIOJob( TQString( "/headers/%1" ).arg( *newMails.begin() ) );
-  connect( pop3Job, SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), this, SLOT( slotReceiveHeader( TDEIO::Job*, const TQByteArray & ) ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotHeaderDownloaded( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), this, TQ_SLOT( slotReceiveHeader( TDEIO::Job*, const TQByteArray & ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotHeaderDownloaded( TDEIO::Job* ) ) );
 
 }
 
@@ -1490,8 +1490,8 @@ void ConfigElem::getNextMailForDownloadActions()
 
   //start job
   startKIOJob( TQString( "/download/%1" ).arg( MailsToDownload.begin().key() ) );
-  connect( pop3Job, SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), SLOT( slotDataMailBody( TDEIO::Job*, const TQByteArray & ) ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotMailDownloadedForAction( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray & ) ), TQ_SLOT( slotDataMailBody( TDEIO::Job*, const TQByteArray & ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotMailDownloadedForAction( TDEIO::Job* ) ) );
 
 }
 
@@ -1748,7 +1748,7 @@ void ConfigElem::commitBeforeRefresh()
 {
   //start job to commit
   startKIOJob( TQString( "/commit" ) );
-  connect( pop3Job, SIGNAL( result( TDEIO::Job* ) ), this, SLOT( slotCommitBeforeRefreshDone( TDEIO::Job* ) ) );
+  connect( pop3Job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotCommitBeforeRefreshDone( TDEIO::Job* ) ) );
 
 }
 
