@@ -14,7 +14,7 @@
 
 #include <string.h>
 
-//QT headers
+//TQt headers
 #include <tqlayout.h>
 #include <tqgroupbox.h>
 #include <tqcheckbox.h>
@@ -43,7 +43,7 @@
  */
 class ConfigActions : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
     /**
