@@ -35,7 +35,7 @@
  */
 class ConfigGeneral : public TDECModule
 {
-Q_OBJECT
+TQ_OBJECT
 
   public:
 
