@@ -54,7 +54,7 @@
 class FilterSetupDialog : public KDialogBase
 {
 
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
    /**
