@@ -45,7 +45,7 @@
 class MailBoxWizard : public TQWizard
 {
 
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
 
